#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

import os
# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
# pylint: disable=C0301,R0913,R0914,W0613,R0912,R0915,E0401,C0413,C0103,C0116
import re
import sys

import pytest

from youqu3 import logger
from youqu3 import setting

os.environ["DISPLAY"] = ":0"


class Run:
    """
    本地执行器
    """

    __author__ = "Mikigo <huangmingqiang@uniontech.com>"

    def __init__(
            self,
            keywords=None,
            tags=None,
            **kwargs,
    ):
        logger("INFO")

        self.keywords = keywords
        self.tags = tags

    @staticmethod
    def make_dir(dirs):
        try:
            dirs = os.path.expanduser(dirs)
            if not os.path.exists(dirs):
                os.makedirs(dirs)
        except FileExistsError:
            pass

    def generate_pytest_cmd(self):
        cmd = ["pytest"]

        if self.keywords:
            self.set_recursion_limit(self.keywords)
            cmd.extend(["-k", f"'{self.keywords}'"])
        if self.tags:
            self.set_recursion_limit(self.tags)
            cmd.extend(["-m", f"'{self.tags}'"])
        return cmd

    @staticmethod
    def set_recursion_limit(strings):
        len_tags = len(re.split("or |and |not ", strings))
        if len_tags >= 999:
            sys.setrecursionlimit(len_tags + 100)

    def run(self):
        run_test_cmd_list = self.generate_pytest_cmd()

        pytest.main([i.strip("'") for i in run_test_cmd_list[1:]])


if __name__ == "__main__":
    Run().run()



import click
from rich.console import Console

console = Console()


@click.group()
def cli():
    console.print(
        "YouQu3:dragon:",
        style="blue",
    )


@cli.command()
@click.option("-k", "--keywords", default=None, type=click.STRING, help="keywords")
@click.option("-t", "--tags", default=None, type=click.STRING, help="tags")
def run(
        keywords,
        tags,
):
    """RUN模式"""
    console.print("youqu3 run", style="blue")
    args = {
        "keywords": keywords,
        "tags": tags,
    }
    console.print(args)
    from youqu3.driver.run import Run
    Run(*args).run()


@cli.command()
def remote():
    """REMOTE模式"""
    console.print("Remote Running YouQu3")


if __name__ == '__main__':
    cli()



from youqu3._setting._dynamic import _DynamicSetting


class _Setting(_DynamicSetting):
    """Global Config"""

    MAX_FAIL = 1
    TIMEOUT = 300
    LOG_LEVEL = "INFO"
    RERUNS = 1
    RECORD_FAILED_CASE = 1


setting = _Setting()



#!/usr/bin/python3
# -*- coding: utf-8 -*-

from funnylog import log
from funnylog import logger

from youqu3._setting import setting as setting

try:
    from youqu_imagecenter_rpc import ImageCenter as ImageCenter

    HAS_IMAGECENTER = False
except ImportError:
    HAS_IMAGECENTER = False

try:
    from pdocr_rpc import OCR as OCR

    HAS_OCR = True
except ImportError:
    HAS_OCR = False

try:
    from youqu_dogtail import DogtailUtils as Dogtail

    HAS_DOGTAIL = True
except ImportError:
    HAS_DOGTAIL = False

try:
    from youqu_mousekey import MouseKey as MouseKey

    HAS_MOUSEKEY = True
except ImportError:
    HAS_MOUSEKEY = False

__all__ = [
    "YouQu",
    "ImageCenter",
    "OCR",
    "Dogtail",
    "setting",
    "log",
    "logger",
]

if HAS_IMAGECENTER and HAS_OCR and HAS_MOUSEKEY:
    class YouQu(ImageCenter, OCR, MouseKey):
        ...
elif HAS_IMAGECENTER and HAS_OCR:
    class YouQu(ImageCenter, OCR):
        ...
elif HAS_IMAGECENTER and HAS_MOUSEKEY:
    class YouQu(ImageCenter, MouseKey):
        ...
elif HAS_OCR and HAS_MOUSEKEY:
    class YouQu(OCR, MouseKey):
        ...
elif HAS_IMAGECENTER:
    class YouQu(ImageCenter):
        ...
elif HAS_OCR:
    class YouQu(OCR):
        ...
elif HAS_MOUSEKEY:
    class YouQu(MouseKey):
        ...



import os
import getpass
import pathlib
import platform


class ArchName:
    x86 = "x86_64"
    aarch64 = "aarch64"
    loongarch64 = "loongarch64"
    mips64 = "mips64"
    sw64 = "sw64"


class DisplayServer:
    wayland = "wayland"
    x11 = "x11"


class _DynamicSetting:
    ARCH = platform.machine().lower()
    HOME = str(pathlib.Path.home())
    USERNAME = getpass.getuser()

    DISPLAY_SERVER = (
                         os.popen("cat ~/.xsession-errors | grep XDG_SESSION_TYPE | head -n 1")
                         .read()
                         .split("=")[-1]
                         .strip("\n")
                     ) or ("x11" if os.popen("ps -ef | grep -v grep | grep kwin_x11").read() else "wayland")

    IS_X11: bool = DISPLAY_SERVER == DisplayServer.x11
    IS_WAYLAND: bool = DISPLAY_SERVER == DisplayServer.wayland
